@@ -8,12 +8,12 @@ set -e
 #${AUTORECONF:-autoreconf} -v -I tools
 #
 # Unfortunately, Autoconf 2.61's autoreconf(1) (found in Mac OS X 10.5
-# Leapard) neglects to pass the -I on to aclocal(1), which is
+# Leopard) neglects to pass the -I on to aclocal(1), which is
 # precisely where we need it!  So we do basically what it would have
 # done.
 
 run () {
-    echo $0: running: "$@"
+    test "${V}" = 1 && echo $0: running: "$@"
     "$@"
 }
 
