@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2014 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,12 +17,7 @@
 #include "tig/view.h"
 
 extern struct view blob_view;
-
-static inline void
-open_blob_view(struct view *prev, enum open_flags flags)
-{
-	open_view(prev, &blob_view, flags);
-}
+void open_blob_view(struct view *prev, enum open_flags flags);
 
 #endif
 /* vim: set ts=8 sw=8 noexpandtab: */
