@@ -73,7 +73,7 @@ blame_update_file_name_visibility(struct view *view)
 			  !state->auto_filename_display);
 }
 
-static bool
+static enum status_code
 blame_open(struct view *view, enum open_flags flags)
 {
 	struct blame_state *state = view->private;
@@ -81,16 +81,6 @@ blame_open(struct view *view, enum open_flags flags)
 	char path[SIZEOF_STR];
 	size_t i;
 
-	if (opt_blame_options) {
-		for (i = 0; opt_blame_options[i]; i++) {
-			if (prefixcmp(opt_blame_options[i], "-C"))
-				continue;
-			state->auto_filename_display = true;
-		}
-	}
-
-	blame_update_file_name_visibility(view);
-
 	if (is_initial_view(view)) {
 		/* Finish validating and setting up blame options */
 		if (!opt_file_args || opt_file_args[1])
@@ -98,8 +88,10 @@ blame_open(struct view *view, enum open_flags flags)
 
 		string_ncopy(view->env->file, opt_file_args[0], strlen(opt_file_args[0]));
 
-		opt_blame_options = opt_cmdline_args;
-		opt_cmdline_args = NULL;
+		if (opt_cmdline_args) {
+			opt_blame_options = opt_cmdline_args;
+			opt_cmdline_args = NULL;
+		}
 
 		/*
 		 * flags (like "--max-age=123") and bottom limits (like "^foo")
@@ -124,27 +116,34 @@ blame_open(struct view *view, enum open_flags flags)
 		}
 	}
 
-	if (!view->env->file[0]) {
-		report("No file chosen, press %s to open tree view",
-			get_view_key(view, REQ_VIEW_TREE));
-		return false;
-	}
-
-	if (!view->prev && *repo.prefix && !(flags & (OPEN_RELOAD | OPEN_REFRESH))) {
-		string_copy(path, view->env->file);
-		if (!string_format(view->env->file, "%s%s", repo.prefix, path)) {
-			report("Failed to setup the blame view");
-			return false;
+	if (opt_blame_options) {
+		for (i = 0; opt_blame_options[i]; i++) {
+			if (prefixcmp(opt_blame_options[i], "-C"))
+				continue;
+			state->auto_filename_display = true;
 		}
 	}
 
-	if (*view->env->ref || !begin_update(view, repo.cdup, file_argv, flags)) {
+	blame_update_file_name_visibility(view);
+
+	if (!view->env->file[0])
+		return error("No file chosen, press %s to open tree view",
+			     get_view_key(view, REQ_VIEW_TREE));
+
+	if (!view->prev && *repo.prefix && !(flags & (OPEN_RELOAD | OPEN_REFRESH))) {
+		string_copy(path, view->env->file);
+		if (!string_format(view->env->file, "%s%s", repo.prefix, path))
+			return error("Failed to setup the blame view");
+	}
+
+	if (*view->env->ref || begin_update(view, repo.cdup, file_argv, flags) != SUCCESS) {
 		const char *blame_cat_file_argv[] = {
 			"git", "cat-file", "blob", "%(ref):%(file)", NULL
 		};
+		enum status_code code = begin_update(view, repo.cdup, blame_cat_file_argv, flags);
 
-		if (!begin_update(view, repo.cdup, blame_cat_file_argv, flags))
-			return false;
+		if (code != SUCCESS)
+			return code;
 	}
 
 	/* First pass: remove multiple references to the same commit. */
@@ -170,11 +169,11 @@ blame_open(struct view *view, enum open_flags flags)
 	string_copy_rev(state->history_state.id, view->env->ref);
 	state->history_state.filename = get_path(view->env->file);
 	if (!state->history_state.filename)
-		return false;
+		return ERROR_OUT_OF_MEMORY;
 	string_format(view->vid, "%s", view->env->file);
 	string_format(view->ref, "%s ...", view->env->file);
 
-	return true;
+	return SUCCESS;
 }
 
 static struct blame_commit *
@@ -240,7 +239,7 @@ blame_read_file(struct view *view, struct buffer *buf, struct blame_state *state
 		if (failed_to_load_initial_view(view))
 			die("No blame exist for %s", view->vid);
 
-		if (view->lines == 0 || !begin_update(view, repo.cdup, blame_argv, OPEN_EXTRA)) {
+		if (view->lines == 0 || begin_update(view, repo.cdup, blame_argv, OPEN_EXTRA) != SUCCESS) {
 			report("Failed to load blame data");
 			return true;
 		}
@@ -286,7 +285,7 @@ blame_read(struct view *view, struct buffer *buf, bool force_stop)
 	if (!state->commit) {
 		state->commit = read_blame_commit(view, buf->data, state);
 		string_format(view->ref, "%s %2zd%%", view->vid,
-			      view->lines ? state->blamed * 100 / view->lines : 0);
+			      view->lines ? 5 * (size_t) (state->blamed * 20 / view->lines) : 0);
 
 	} else if (parse_blame_info(state->commit, state->author, buf->data)) {
 		bool update_view_columns = true;
