@@ -65,9 +65,9 @@ parse_author_line(char *ident, const struct ident **author, struct time *time)
 
 	if (nameend && emailend)
 		*nameend = *emailend = 0;
-	name = chomp_string(ident);
+	name = string_trim(ident);
 	if (nameend)
-		email = chomp_string(nameend + 1);
+		email = string_trim(nameend + 1);
 	if (!*name)
 		name = *email ? email : unknown_ident.name;
 	if (!*email)
@@ -267,25 +267,31 @@ get_path(const char *path)
 	return entry->path;
 }
 
-DEFINE_STRING_MAP(author_cache, const struct ident *, email, 32)
+DEFINE_STRING_MAP(author_cache, const struct ident *, key, 32)
 
 /* Small author cache to reduce memory consumption. No entries
  * are ever freed. */
 struct ident *
 get_author(const char *name, const char *email)
 {
-	struct ident *ident = string_map_get(&author_cache, email);
+	char key[SIZEOF_STR + SIZEOF_STR];
+	struct ident *ident;
 
+	string_format(key, "%s%s", email, name);
+
+	ident = string_map_get(&author_cache, key);
 	if (ident)
 		return ident;
 
 	ident = calloc(1, sizeof(*ident));
 	if (!ident)
 		return NULL;
+	ident->key = strdup(key);
 	ident->name = strdup(name);
 	ident->email = strdup(email);
-	if (!ident->name || !ident->email ||
-	    !string_map_put(&author_cache, email, ident)) {
+	if (!ident->key || !ident->name || !ident->email ||
+	    !string_map_put(&author_cache, key, ident)) {
+		free((void *) ident->key);
 		free((void *) ident->name);
 		free((void *) ident->email);
 		free(ident);
