@@ -126,6 +126,20 @@ prompt_default_handler(struct input *input, struct key *key)
 	}
 }
 
+static enum input_status
+prompt_script_handler(struct input *input, struct key *key)
+{
+	switch (key_to_value(key)) {
+	case KEY_RETURN:
+	case KEY_ENTER:
+	case '\n':
+		return INPUT_STOP;
+
+	default:
+		return INPUT_OK;
+	}
+}
+
 static enum input_status
 prompt_yesno_handler(struct input *input, struct key *key)
 {
@@ -457,6 +471,10 @@ readline_init(void)
 	rl_attempted_completion_function = readline_completion;
 
 	rl_completion_display_matches_hook = readline_display_matches;
+
+	/* Let ncurses deal with the LINES and COLUMNS environment variables */
+	rl_change_environment = 0;
+	rl_catch_sigwinch = 0;
 }
 
 static void sigint_absorb_handler(int sig) {
@@ -590,7 +608,7 @@ prompt_init(void)
 
 	last_entry = history_get(history_length);
 	if (last_entry)
-		string_copy(argv_env.search, last_entry->line);
+		string_ncopy(argv_env.search, last_entry->line, strlen(last_entry->line));
 }
 #else
 char *
@@ -1047,7 +1065,6 @@ run_prompt_command(struct view *view, const char *argv[])
 			prompt_update_display(flags);
 
 		} else {
-			request = view_can_refresh(view) ? REQ_REFRESH : REQ_SCREEN_REDRAW;
 			if (!strcmp(cmd, "color"))
 				init_colors();
 			resize_display();
@@ -1064,7 +1081,7 @@ exec_run_request(struct view *view, struct run_request *req)
 	const char **argv = NULL;
 	bool confirmed = false;
 	enum request request = REQ_NONE;
-	char cmd[SIZEOF_CMD];
+	char cmd[SIZEOF_MED_STR];
 	const char *req_argv[SIZEOF_ARG];
 	int req_argc = 0;
 
@@ -1095,7 +1112,7 @@ exec_run_request(struct view *view, struct run_request *req)
 
 		if (confirmed)
 			open_external_viewer(argv, repo.cdup, req->flags.silent,
-					     !req->flags.exit, req->flags.echo, false, "");
+					     !req->flags.exit, req->flags.echo, req->flags.quick, false, "");
 	}
 
 	if (argv)
@@ -1120,10 +1137,15 @@ exec_run_request(struct view *view, struct run_request *req)
 enum request
 open_prompt(struct view *view)
 {
-	char *cmd = read_prompt(":");
+	char *cmd;
 	const char *argv[SIZEOF_ARG] = { NULL };
 	int argc = 0;
 
+	if (is_script_executing())
+		cmd = read_prompt_incremental(" ", false, true, prompt_script_handler, NULL);
+	else
+		cmd = read_prompt(":");
+
 	if (cmd && *cmd && !argv_from_string(argv, &argc, cmd)) {
 		report("Too many arguments");
 		return REQ_NONE;
