@@ -111,6 +111,8 @@ file="\$1"
 lineno="\$(expr "\$1" : '+\([0-9]*\)')"
 if [ -n "\$lineno" ]; then
 	file="\$2"
+else
+	lineno=1,5
 fi
 
 printf '%s\\n' "\$*" >> "$HOME/editor.log"
@@ -136,6 +138,10 @@ tty_reset()
 	fi
 }
 
+### Testing API AsciiDoc
+#|
+#| file(filename, [content, ...]) [< content]::
+#|
 file() {
 	path="$1"; shift
 
@@ -151,6 +157,10 @@ file() {
 	fi
 }
 
+### Testing API AsciiDoc
+#|
+#| tig_script(name, content, [content, ...])::
+#|
 tig_script() {
 	name="$1"; shift
 	prefix="${name:+$name.}"
@@ -167,22 +177,42 @@ tig_script() {
 		> "$TIG_SCRIPT"
 }
 
+### Testing API AsciiDoc
+#|
+#| steps(content, [content, ...])::
+#|
 steps() {
 	tig_script "" "$@"
 }
 
+### Testing API AsciiDoc
+#|
+#| stdin([content, ...]) [< content]::
+#|
 stdin() {
 	file "stdin" "$@"
 }
 
+### Testing API AsciiDoc
+#|
+#| tigrc([content, ...]) [< content]::
+#|
 tigrc() {
 	file "$HOME/.tigrc" "$@"
 }
 
+### Testing API AsciiDoc
+#|
+#| gitconfig(content, ...)::
+#|
 gitconfig() {
 	file "$HOME/.gitconfig" "$@"
 }
 
+### Testing API AsciiDoc
+#|
+#| in_work_dir(command, [args, ...])::
+#|
 in_work_dir()
 {
 	(cd "$work_dir" && "$@")
@@ -238,6 +268,7 @@ diff_color_arg=
 indent='            '
 verbose=
 debugger=
+runner=exec
 trace=
 todos=
 valgrind=
@@ -273,6 +304,10 @@ filter_file_ok || exit 0   # silently exit caller who sourced this file
 # Test runners and assertion checking.
 #
 
+### Testing API AsciiDoc
+#|
+#| assert_equals(filename, [whitespace, note, ...]) < expected::
+#|
 assert_equals()
 {
 	file="$1"; shift
@@ -307,6 +342,10 @@ assert_equals()
 	fi
 }
 
+### Testing API AsciiDoc
+#|
+#| assert_not_exists(filename)::
+#|
 assert_not_exists()
 {
 	file="$1"; shift
@@ -346,6 +385,10 @@ printf '%s\\n' "\$lhs" >> "$HOME/$vars_file"
 printf '%s\\n' "\$rhs" >> "$expected_vars_file"
 EOF
 
+### Testing API AsciiDoc
+#|
+#| assert_vars(count)::
+#|
 assert_vars()
 {
 	if [ -n "${1:-}" ]; then
@@ -419,6 +462,10 @@ test_todo_message()
 	printf '[TODO] Not yet expected to pass%s\n' "$explanation"
 }
 
+### Testing API AsciiDoc
+#|
+#| test_todo([note, ...])::
+#|
 test_todo()
 {
 	if [ -n "$todos" ]; then
@@ -428,6 +475,10 @@ test_todo()
 	test_todo_message "$*" >> .test-skipped
 }
 
+### Testing API AsciiDoc
+#|
+#| test_timeout(seconds)::
+#|
 test_timeout()
 {
 	if [ -z "${1:-}" ]; then
@@ -437,6 +488,10 @@ test_timeout()
 	timeout="${1:-}"
 }
 
+### Testing API AsciiDoc
+#|
+#| require_git_version(version, [note, ...])::
+#|
 require_git_version()
 {
 	git_version="$(git version | sed 's/git version \([0-9\.]*\).*/\1/')"
@@ -453,6 +508,19 @@ require_git_version()
 	fi
 }
 
+has_readline()
+{
+	if tig --version | grep readline >/dev/null 2>&1; then
+		return 0
+	else
+		return 1
+	fi
+}
+
+### Testing API AsciiDoc
+#|
+#| test_require(git-worktree, address-sanitizer, diff-highlight, readline)::
+#|
 test_require()
 {
 	while [ $# -gt 0 ]; do
@@ -478,6 +546,12 @@ test_require()
 				test_skip "The test requires diff-highlight, usually found in share/git-core-contrib"
 			fi
 			;;
+		readline)
+			if ! has_readline; then
+				test_skip "The test requires a tig compiled with readline"
+			fi
+			;;
+
 		*)
 			test_skip "Unknown feature requirement: $feature"
 		esac
@@ -486,7 +560,8 @@ test_require()
 
 test_exec_work_dir()
 {
-	printf '=== %s ===\n' "$*" >> "$HOME/test-exec.log"
+	cmd="$@"
+	printf '=== %s ===\n' "$cmd" >> "$HOME/test-exec.log"
 	test_exec_log="$HOME/test-exec.log.tmp"
 	rm -f -- "$test_exec_log"
 
@@ -497,7 +572,6 @@ test_exec_work_dir()
 
 	cat < "$test_exec_log" >> "$HOME/test-exec.log"
 	if [ "$test_exec_exit_code" != 0 ]; then
-		cmd="$*"
 		printf "[FAIL] unexpected exit code while executing '%s': %s\n" "$cmd" "$test_exec_exit_code" >> .test-result
 		cat < "$test_exec_log" >> .test-result
 		# Exit gracefully to allow additional tests to run
@@ -505,6 +579,10 @@ test_exec_work_dir()
 	fi
 }
 
+### Testing API AsciiDoc
+#|
+#| test_setup()::
+#|
 test_setup()
 {
 	if [ -e .test-skipped ]; then
@@ -570,6 +648,18 @@ valgrind_exec()
 	return "$valgrind_status_code"
 }
 
+### Testing API AsciiDoc
+#|
+#| test_tig()::
+#|
+#|	Set up a controlled environment and report the test result.
+#|	Input to be processed via stdin is passed and stderr is captured and
+#|	can be used for later assertions.
+#|	Example
+#| --------------------------------------------------------------------------------
+#| test_tig show 1a2b3c4d5e6f
+#| --------------------------------------------------------------------------------
+#|
 test_tig()
 {
 	name="$TEST_NAME"
@@ -597,7 +687,6 @@ test_tig()
 			"$debugger" tig "$@"
 		else
 			set +e
-			runner=exec
 			if [ "$expected_status_code" = 0 ] && [ -n "$valgrind" ]; then
 				runner=valgrind_exec
 				if [ "$timeout" -gt 0 ]; then
@@ -641,11 +730,19 @@ test_tig()
 	fi
 }
 
+### Testing API AsciiDoc
+#|
+#| test_graph() < expected::
+#|
 test_graph()
 {
 	test-graph "$@" > stdout 2> stderr.orig
 }
 
+### Testing API AsciiDoc
+#|
+#| test_case([--before=<string>, --after=<string>, --script=<string>, --args=<string>, --cwd=<string>, --tigrc=<string>, --assert-stderr=<string>, --todo=<string>, --subshell=<string>, --timeout=<string>]) < expected::
+#|
 test_case()
 {
 	name="$1"; shift
@@ -673,6 +770,10 @@ test_case()
 	done
 }
 
+### Testing API AsciiDoc
+#|
+#| run_test_cases()::
+#|
 run_test_cases()
 {
 	if [ ! -e test-cases ]; then
@@ -680,6 +781,7 @@ run_test_cases()
 	fi
 	test_setup
 	while read -r name <&3; do
+		export TEST_CASE="$name"
 		if [ -n "$filter" ]; then
 			matcher="$name"
 			_filter_case_part="${filter#*:}"
